@@ -7,7 +7,8 @@ from .bar import (
 from .correlation import plot_correlation_figure
 from .matrix import plot_matrix_figure
 from .circos import plot_symmetric_circle_figure, plot_asymmetric_circle_figure
-from .brain_surface_old import (
+from .brain_surface import plot_brain_surface_figure
+from .brain_surface_deprecated import (
     plot_human_brain_figure,
     plot_human_hemi_brain_figure,
     plot_macaque_brain_figure,
@@ -15,7 +16,6 @@ from .brain_surface_old import (
     plot_chimpanzee_brain_figure,
     plot_chimpanzee_hemi_brain_figure,
 )
-from .brain_surface import plot_brain_surface_figure
 from .brain_connection import plot_brain_connection_figure, save_brain_connection_frames
 
 from importlib.metadata import version, PackageNotFoundError
@@ -37,7 +37,7 @@ __all__ = [
     "plot_symmetric_circle_figure",
     "plot_asymmetric_circle_figure",
     "plot_brain_connection_figure",
-    "save_brain_connection_frames"
+    "save_brain_connection_frames",
 ]
 
 try:
